@@ -1,11 +1,11 @@
 package String::TtyLength;
-$String::TtyLength::VERSION = '0.01_05'; # TRIAL
+$String::TtyLength::VERSION = '0.01_06'; # TRIAL
 
-$String::TtyLength::VERSION = '0.0105';use 5.006;
+$String::TtyLength::VERSION = '0.0106';use 5.006;
 use strict;
 use warnings;
 use parent 'Exporter';
-use Unicode::EastAsianWidth;
+use Unicode::EastAsianWidth 12.0;
 
 our @EXPORT_OK = qw/ tty_length tty_width /;
 
